<?php

namespace Drupal\sdc;

class Utilities {

  /**
   * Takes two absolute paths and makes one relative to the other.
   *
   * @param string $full_path
   *   The full path.
   * @param string $base
   *   The base to make relative to.
   *
   * @return string
   *   The relative path.
   */
  public static function makePathRelative(string $full_path, string $base): string {
    $app_root = \Drupal::root();
    $base_from_root = str_starts_with($base, $app_root)
      ? substr($base, strlen($app_root) + 1)
      : $base;
    $num_dots = empty($base_from_root)
      ? 0
      : count(explode(DIRECTORY_SEPARATOR, $base_from_root));
    $dots = implode(DIRECTORY_SEPARATOR, array_fill(0, $num_dots, '..'));
    $full_path_from_root = str_starts_with($full_path, $app_root)
      ? substr($full_path, strlen($app_root) + 1)
      : $full_path;
    return sprintf(
      '%s%s%s',
      $dots ?: '.',
      DIRECTORY_SEPARATOR,
      $full_path_from_root,
    );
  }

}
